@@ -9,17 +9,30 @@ from ..views import BaseView, expose
 
 
 class BaseChartView(BaseView):
+    """
+        This is the base class for all chart views. 
+                   
+    """
     chart_template = 'appbuilder/general/charts/chart.html'
     chart_widget = ChartWidget
+    
     chart_title = 'Chart'
+    """ A title to be displayed on the chart """
     chart_type = 'PieChart'
+    """ The chart type PieChart or ColumnChart """
     chart_3d = 'true'
+    """ Will display in 3D? """
     width = 400
+    """ The width """
     height = '400px'
     group_by = ''
+    
     label_columns = []
+    """ The labels for the columns """
     group_by_columns = []
+    """ A list of columns to be possibly grouped by """
     datamodel = None
+    """ Your sqla model you must initialize it like datamodel = SQLAModel(Permission, session) """
     
 
     def _get_chart_widget(self, value_columns = [], widgets = {}):        
@@ -32,7 +45,11 @@ class BaseChartView(BaseView):
     
 
 class ChartView(BaseChartView):
-    
+    """
+        Provides a simple (and hopefully nice) way to draw charts on your application.
+
+        This will show Google Charts based on group by of your tables.                
+    """
     
     @expose('/chart/')
     @has_access
@@ -51,6 +68,12 @@ class ChartView(BaseChartView):
                                                 baseapp = self.baseapp)
     
 class TimeChartView(BaseChartView):
+    """
+        Provides a simple way to draw some time charts on your application.
+
+        This will show Google Charts based on count and group by month and year for your tables.
+    """
+
     chart_template = 'appbuilder/general/charts/chart_time.html'
     chart_type = 'ColumnChart'
     
