@@ -1,11 +1,13 @@
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy import Table, Column, Integer, String, MetaData, ForeignKey, DateTime
+from sqlalchemy.orm import relationship
 import sqlalchemy.types as types
 from sqlalchemy.types import String
 from flask import g
 import uuid
 import datetime
 
+
 #try:
 #    from app import db
 #except ImportError:
@@ -42,7 +44,7 @@ class AuditMixin(BaseMixin):
 
     @declared_attr
     def created_by_fk(cls):
-        return Column(Integer, ForeignKey('user.id'),
+        return Column(Integer, ForeignKey('ab_user.id'),
                 default=cls.get_user_id,nullable=False)
 
     @declared_attr
@@ -51,7 +53,7 @@ class AuditMixin(BaseMixin):
 
     @declared_attr
     def changed_by_fk(cls):
-        return Column(Integer, ForeignKey('user.id'),
+        return Column(Integer, ForeignKey('ab_user.id'),
                 default=cls.get_user_id,onupdate=cls.get_user_id,nullable=False)
 
     @declared_attr
