@@ -28,8 +28,11 @@ def expose(url='/', methods=('GET',)):
     
 class BaseView(object):
     """
-    Base View for all Views
-    includes permission, app info
+        All views derive from this class. it's constructor will register your exposed urls on flask as a Blueprint.
+
+        This class does not expose any urls, but provides a common base for all views.
+        
+        Extend this class if you want to expose methods for your own templates        
     """
 
     baseapp = None
@@ -37,6 +40,8 @@ class BaseView(object):
     endpoint = None
     
     route_base = None
+    """ Override this if you want to define your own relative url """
+    
     template_folder = 'templates'
     static_folder='static'
     
@@ -47,8 +52,8 @@ class BaseView(object):
 
     def __init__(self):
         """
-        Initialization of base permissions
-        based on exposed methods and actions
+            Initialization of base permissions
+            based on exposed methods and actions
         """
         if not self.base_permissions:
             self.base_permissions = [
@@ -68,14 +73,14 @@ class BaseView(object):
                         endpoint = None, 
                         static_folder = None):
         """
-            Create Flask blueprint.
+            Create Flask blueprint. You will generally not use it
             
-            param baseapp:
+            :param baseapp:
                the BaseApp application
-            param endpoint:
+            :param endpoint:
                endpoint override for this blueprint, will assume class name if not provided
-            param static_folder:
-               the relative override for static forder, if omited application will use the baseapp static
+            :param static_folder:
+               the relative override for static folder, if ommited application will use the baseapp static
         """
         # Store BaseApp instance
         self.baseapp = baseapp
@@ -116,23 +121,23 @@ class BaseView(object):
 
     def _prettify_name(self, name):
         """
-        Prettify pythonic variable name.
+            Prettify pythonic variable name.
 
-        For example, 'hello_world' will be converted to 'Hello World'
+            For example, 'hello_world' will be converted to 'Hello World'
 
-        :param name:
-            Name to prettify
+            :param name:
+                Name to prettify.
         """
         return re.sub(r'(?<=.)([A-Z])', r' \1', name)
 
     def _prettify_column(self, name):
         """
-        Prettify pythonic variable name.
+            Prettify pythonic variable name.
 
-        For example, 'hello_world' will be converted to 'Hello World'
+            For example, 'hello_world' will be converted to 'Hello World'
 
-        :param name:
-            Name to prettify
+            :param name:
+                Name to prettify.
         """
         return name.replace('_', ' ').title()
 
@@ -144,7 +149,7 @@ class BaseView(object):
             try:
                 return url_for('%s.%s' % (self.endpoint, self.default_view))
             except:
-                return '/'
+                return url_for('%s.%s' % (self.baseapp.indexview.endpoint, self.baseapp.indexview.default_view))
             
 
     def _get_group_by_args(self):
@@ -154,10 +159,10 @@ class BaseView(object):
 
     def _get_page_args(self, pages = {}):
         """
-        Get page arguments, return a dictionary
-        { <VIEW_NAME>: PAGE_NUMBER }
+            Get page arguments, return a dictionary
+            { <VIEW_NAME>: PAGE_NUMBER }
         
-        Arguments are passed: page_<VIEW_NAME>=<PAGE_NUMBER>
+            Arguments are passed: page_<VIEW_NAME>=<PAGE_NUMBER>
         
         """
         for arg in request.args:
@@ -170,10 +175,10 @@ class BaseView(object):
 
     def _get_order_args(self, orders = {}):
         """
-        Get order arguments, return a dictionary
-        { <VIEW_NAME>: (ORDER_COL, ORDER_DIRECTION) }
+            Get order arguments, return a dictionary
+            { <VIEW_NAME>: (ORDER_COL, ORDER_DIRECTION) }
         
-        Arguments are passed like: _oc_<VIEW_NAME>=<COL_NAME>&_od_<VIEW_NAME>='asc'|'desc'
+            Arguments are passed like: _oc_<VIEW_NAME>=<COL_NAME>&_od_<VIEW_NAME>='asc'|'desc'
         
         """
         for arg in request.args:
@@ -203,38 +208,37 @@ class BaseView(object):
 
 class IndexView(BaseView):
     """
-    Index View
-    A simple view that implements the index for the site
+        A simple view that implements the index for the site
     """
 
     route_base = ''
-
+    default_view = 'index'
     index_template = 'appbuilder/index.html'
 
     @expose('/')
-    @expose('/index/')
     def index(self):
         return render_template(self.index_template, baseapp = self.baseapp)
 
-"""
-----------------------------------
-     SIMPLE FORM VIEW
-----------------------------------
-"""
+
 class SimpleFormView(BaseView):
     """
-    Simple Form View
-    Basic functions used on forms:
-    override form_get and form_post
+        View for presenting you own forms
+        Derive from this view to provide some base processing for your costumized form views.
+
+        Notice that this class derives from BaseView so all properties from the parent class can be overrided also.
+
+        Implement form_get and form_post to implement your form pre-processing and post-processing
     """
 
     form_template = 'appbuilder/general/model/edit.html'
-    """ Widgets """
+    
     edit_widget = FormWidget
-
     form_title = 'Form Title'
+    """ The form title to be displayed """
     form_columns = []
+    """ The form columns to include """
     form = None
+    """ The WTF form to render """
     
     @expose("/form", methods=['GET'])
     @has_access
@@ -286,56 +290,85 @@ class SimpleFormView(BaseView):
 
 
 class BaseCRUDView(BaseView):
+    """
+        The base class of GeneralView, all properties are inherited
+        Customize GeneralView overriding this properties
+    """
+    
     
     datamodel = None
+    """ Your sqla model you must initialize it like datamodel = SQLAModel(Permission, session) """
     related_views = []
+    """ Views that will be displayed related with this one, must be instantiated """
     
-    """ Titles """
     list_title = ""
+    """ List Title """
     show_title = ""
+    """ Show Title """
     add_title = ""
+    """ Add Title """
     edit_title = ""
+    """ Edit Title """
 
-    """ Include Columns """
+    
     list_columns = []
+    """ Include Columns for lists view """
     show_columns = []
+    """ Include Columns for show view """
     add_columns = []
+    """ Include Columns for add view """
     edit_columns = []
+    """ Include Columns for edit view """
     order_columns = []
+    """ Allowed order columns """
     search_columns = []
+    """ Allowed search columns """
 
     label_columns = {}
     description_columns = {}
     
     page_size = 30
 
-    """ fieldsets [(<'TITLE'|None>, {'fields':[<F1>,<F2>,...]}),....] """
+    
     show_fieldsets = []
+    """ show fieldsets [(<'TITLE'|None>, {'fields':[<F1>,<F2>,...]}),....] """
     add_fieldsets = []
+    """ add fieldsets [(<'TITLE'|None>, {'fields':[<F1>,<F2>,...]}),....] """
     edit_fieldsets = []
+    """ edit fieldsets [(<'TITLE'|None>, {'fields':[<F1>,<F2>,...]}),....] """
 
-    """ Forms """
+    
     add_form = None
+    """ Your own add WTF form for Add """
     edit_form = None
+    """ Your own add WTF form for Edit """
     search_form = None
+    """ Your own add WTF form for Search """
 
     validators_columns = {}
 
-    """ Template Layouts """
+    
     list_template = 'appbuilder/general/model/list.html'
+    """ Your own add jinja2 template for list """
     edit_template = 'appbuilder/general/model/edit.html'
+    """ Your own add jinja2 template for edit """
     add_template = 'appbuilder/general/model/add.html'
+    """ Your own add jinja2 template for add """
     show_template = 'appbuilder/general/model/show.html'
-
-    """ Widgets """
-    list_widget = ListWidget
-    edit_widget = FormWidget
-    add_widget = FormWidget
-    show_widget = ShowWidget
-    search_widget = SearchWidget
+    """ Your own add jinja2 template for show """
 
     
-    """ Additional Widgets """
+    list_widget = ListWidget
+    """ List widget override """
+    edit_widget = FormWidget
+    """ Edit widget override """
+    add_widget = FormWidget
+    """ Add widget override """
+    show_widget = ShowWidget
+    """ Show widget override """
+    search_widget = SearchWidget
+    """ Search widget override """
+        
     show_additional_links = []
 
     
@@ -404,11 +437,6 @@ class BaseCRUDView(BaseView):
         super(BaseCRUDView, self).__init__(**kwargs)
     
 
-    """
-    --------------------------
-            WIDGET METHODS
-    --------------------------
-    """
     def _get_related_list_widget(self, item, related_view, 
                                 filters={}, order_column='', order_direction='',
                                 page=None, page_size=None):
@@ -504,42 +532,56 @@ class BaseCRUDView(BaseView):
         print self.__class__.__name__, "EDIT COL", self.edit_columns
         print self.__class__.__name__, "LIST COL", self.list_columns
 
-    """
-    -----------------------------------
-     Methods to override
-    -----------------------------------
-    """
+    
     @classmethod
     def pre_update(self, item):
+        """
+            Override this, will be called before update
+        """
         pass
 
     @classmethod
     def post_update(self, item):
+        """
+            Override this, will be called after update
+        """        
         pass
 
     @classmethod
     def pre_add(self, item):
+        """
+            Override this, will be called before add
+        """        
         pass
 
     @classmethod
     def post_add(self, item):
+        """
+            Override this, will be called after update
+        """        
         pass
 
     @classmethod
     def pre_delete(self, item):
+        """
+            Override this, will be called before delete
+        """        
         pass
 
     @classmethod
     def post_delete(self, item):
+        """
+            Override this, will be called after delete
+        """        
         pass
 
 
 
 class GeneralView(BaseCRUDView):
     """
-    General View Class
-    Responsible to handle all CRUD events
-    List, Edit, Add, Show based on models
+        This is the most important view. If you want to automatically implement create, edit, delete, show, and search form your database tables, derive your views from this class.
+
+        Notice that this class derives from BaseView so all properties from the parent class can be overrided also.
     """
 
     def __init__(self, **kwargs):
@@ -669,6 +711,8 @@ class GeneralView(BaseCRUDView):
         if request.method == 'POST':
             form = self.edit_form(request.form)
             form = form.refresh(obj=item)
+            # trick to pass unique validation
+            form._id = pk
             if form.validate():
                 form.populate_obj(item)
 
